@@ -2,13 +2,13 @@ library(RKorAPClient)
 library(highcharter)
 library(tidyverse)
 
-QUERIES <- c("[tt/l=verunfallen]", "Sonnabend") # search in treetagger lemma annotations
+QUERIES <- c("(das|einen|den) Cola") # search in treetagger lemma annotations
 COUNTRIES <- c("AT", "BE", "CH", "DE", "IT", "LU")
 
 VCS <- sprintf("textType=/Zeit.*/ & pubPlaceKey=%s", COUNTRIES) # limit virtual corpus to newspapers and magazines
 
 
-df <- new("KorAPConnection", verbose=TRUE) %>%
+df <- KorAPConnection(verbose=TRUE) %>%
   frequencyQuery(QUERIES, vc=VCS) %>%
   ipm() %>%
   mutate(country = rep(COUNTRIES, length(QUERIES)))
